@@ -1,7 +1,7 @@
 package Pcore::App::API::Backend::Local::UserSession;
 
 use Pcore -role, -sql, -res;
-use Pcore::App::API qw[:ROOT_USER :PRIVATE_TOKEN :INVALIDATE_TYPE :TOKEN_TYPE];
+use Pcore::App::API::Const qw[:ROOT_USER :PRIVATE_TOKEN :INVALIDATE_TYPE :TOKEN_TYPE];
 
 sub _user_session_authenticate ( $self, $private_token ) {
 
