@@ -10,20 +10,16 @@ has argon2_time        => 3;        # PositiveInt;
 has argon2_memory      => '64M';    # Str;
 has argon2_parallelism => 1;        # PositiveInt, default;
 
-sub API_create_hash ( $self, $cb, $str, $args = undef ) {
+sub API_create_hash ( $self, $str, $args = undef ) {
     my $salt = P->random->bytes(32);
 
     my $hash = Crypt::Argon2::argon2i_pass( $str, $salt, $args->{argon2_time} // $self->{argon2_time}, $args->{argon2_memory} // $self->{argon2_memory}, $args->{argon2_parallelism} // $self->{argon2_parallelism}, 32 );
 
-    $cb->( 200, $hash );
-
-    return;
+    return 200, $hash;
 }
 
-sub API_verify_hash ( $self, $cb, $str, $hash ) {
-    $cb->( 200, eval { Crypt::Argon2::argon2i_verify( $hash, $str ) } ? 1 : 0 );
-
-    return;
+sub API_verify_hash ( $self, $str, $hash ) {
+    return 200, eval { Crypt::Argon2::argon2i_verify( $hash, $str ) } ? 1 : 0;
 }
 
 1;
