@@ -3,9 +3,9 @@ package Pcore::App::API::Role::Read;
 use Pcore -const, -role, -sql, -res;
 use Pcore::Util::Scalar qw[is_ref];
 
-has max_limit        => 100;
-has default_limit    => 0;
-has default_order_by => undef;
+has read_max_limit        => 100;
+has read_default_limit    => 0;
+has read_default_order_by => undef;
 
 sub _read ( $self, $total_query, $main_query, $args = undef ) {
     my $dbh = $self->{dbh};
@@ -41,8 +41,8 @@ sub _read ( $self, $total_query, $main_query, $args = undef ) {
     # has results
     my $data = $dbh->selectall( [    #
         $main_query->@*,
-        ORDER_BY( $args->{order_by} || $self->{default_order_by} ),
-        LIMIT( $args->{limit}, max => $self->{max_limit}, default => $self->{default_limit} ),
+        ORDER_BY( $args->{order_by} || $self->{read_default_order_by} ),
+        LIMIT( $args->{limit}, max => $self->{read_max_limit}, default => $self->{read_default_limit} ),
         OFFSET( $args->{offset} ),
     ] );
 
