@@ -36,15 +36,11 @@ sub get_nginx_cfg ($self) {
     }
 : } else {
     location =<: $location :> {
-        return 301 <: $location :>/;
-    }
-
-    location =<: $location :>/ {
         error_page 418 = @backend;
         return 418;
     }
 
-    location <: $location :> {
+    location <: $location :>/ {
         error_page 418 = @backend;
         return 418;
     }
