@@ -1,8 +1,8 @@
 package Pcore::Core::Dump::Dumper;
 
 use Pcore -class, -ansi;
-use Pcore::Lib::Scalar qw[refaddr isweak reftype blessed looks_like_number tainted];
-use Pcore::Lib::Text qw[escape_perl remove_ansi add_num_sep];
+use Pcore::Util::Scalar qw[refaddr isweak reftype blessed looks_like_number tainted];
+use Pcore::Util::Text qw[escape_perl remove_ansi add_num_sep];
 use re qw[];
 use Sort::Naturally qw[nsort];
 use PerlIO::Layers qw[];
@@ -11,7 +11,7 @@ has color  => (0);    # colorize dump
 has tags   => (0);    # do not add tags
 has indent => (4);    # indent spaces
 
-has _indent => ( init_arg => undef );
+has _indent => ( init_arg             => undef );
 has _seen   => ( sub { {} }, init_arg => undef );    # HashRef
 
 our $COLOR = {
