@@ -1,7 +1,7 @@
 package Pcore::Core::Env::Share;
 
 use Pcore -class;
-use Pcore::Lib::Scalar qw[is_plain_scalarref is_plain_arrayref is_plain_hashref];
+use Pcore::Util::Scalar qw[is_plain_scalarref is_plain_arrayref is_plain_hashref];
 
 has _lib_idx  => ( init_arg => undef );    # HashRef
 has _lib_path => ( init_arg => undef );    # ArrayRef
