@@ -1,9 +1,9 @@
 package Pcore::HTTP::Response;
 
 use Pcore -class;
-use Pcore::Lib::Scalar qw[is_plain_scalarref];
+use Pcore::Util::Scalar qw[is_plain_scalarref];
 
-with qw[Pcore::Lib::Result::Role];
+with qw[Pcore::Util::Result::Role];
 
 has url => ();
 
