@@ -1,11 +1,11 @@
 package Pcore::Handle::DBI::Query::GROUP_BY;
 
 use Pcore -const, -class;
-use Pcore::Lib::Scalar qw[is_ref];
+use Pcore::Util::Scalar qw[is_ref];
 
 has _buf => ( required => 1 );    # ArrayRef
 
-sub get_query ( $self, $dbh, $final, $i ) {
+sub GET_SQL_QUERY ( $self, $dbh, $i ) {
     my @sql;
 
     for my $token ( $self->{_buf}->@* ) {
