@@ -3,21 +3,24 @@ package Pcore::Handle::DBI::Query::LIMIT;
 use Pcore -class;
 use Pcore::Util::Scalar qw[is_ref is_plain_scalarref];
 
+has max     => ();
+has default => ();
+
 has _buf => ( required => 1 );    # ArrayRef
 
 sub GET_SQL_QUERY ( $self, $dbh, $i ) {
-    my @bind;
+    my $val;
 
     if ( defined $self->{_buf} ) {
 
         # Scalar value is processed as parameter
         if ( !is_ref $self->{_buf} ) {
-            push @bind, $self->{_buf};
+            $val = $self->{_buf};
         }
 
         # ScalarRef value is processed as parameter
         elsif ( !is_plain_scalarref $self->{_buf} ) {
-            push @bind, $self->{_buf}->$* if defined $self->{_buf}->$*;
+            $val = $self->{_buf}->$* if defined $self->{_buf}->$*;
         }
 
         else {
@@ -25,7 +28,19 @@ sub GET_SQL_QUERY ( $self, $dbh, $i ) {
         }
     }
 
-    return @bind ? ( 'LIMIT $' . $i->$*++, \@bind ) : ( undef, undef );
+    if ( !$val ) {
+        $val = $self->{default} || $self->{max};
+    }
+    elsif ( my $max = $self->{max} ) {
+        $val = $max if $val > $max;
+    }
+
+    if ($val) {
+        return 'LIMIT $' . $i->$*++, [$val];
+    }
+    else {
+        return;
+    }
 }
 
 1;
