@@ -1,7 +1,7 @@
 package Pcore::Handle::DBI::Query::SET;
 
 use Pcore -class;
-use Pcore::Util::Scalar qw[is_ref is_plain_scalarref is_arrayref is_plain_hashref is_blessed_hashref];
+use Pcore::Util::Scalar qw[is_ref is_bool is_plain_scalarref is_arrayref is_plain_hashref is_blessed_hashref];
 
 has _buf => ( required => 1 );    # ArrayRef
 
@@ -45,6 +45,13 @@ sub GET_SQL_QUERY ( $self, $dbh, $i ) {
                     push @bind, $token->{$field};
                 }
 
+                # known boolean objects
+                elsif ( is_bool $token->{$field} ) {
+                    push @sql1, $dbh->quote_id($field) . ' = $' . $i->$*++;
+
+                    push @bind, $token->{$field};
+                }
+
                 # object
                 elsif ( is_blessed_hashref $token->{$field} ) {
                     my ( $sql, $bind ) = $token->{$field}->GET_SQL_QUERY( $dbh, $i );
