@@ -38,23 +38,35 @@ sub parse ( $self, $date ) {
     }
 }
 
-# %a, %d %b %Y %H:%M:%S %z
-sub to_rfc_1123 ($self) {
+*to_http_date = *to_rfc2616 = \&to_rfc7231;
+
+*to_w3cdtf = \&to_iso8601;
+
+# Wed, 09 Feb 94 22:23:32 -0100, two digits year
+sub to_rfc822 ($self) {
+    return $self->strftime('%a, %d %b %y %H:%M:%S %z');
+}
+
+# Wed, 09 Feb 1994 22:23:32 -0100, RFC 822 + 4 digits year
+sub to_rfc1123 ($self) {
     return $self->strftime('%a, %d %b %Y %H:%M:%S %z');
 }
 
-*to_http_date = \&to_rfc_2616;
-
-# %a, %d %b %Y %H:%M:%S GMT
-sub to_rfc_2616 ($self) {
+# Wed, 09 Feb 1994 22:23:32 GMT, RFC 1123 + always in UTC zone
+sub to_rfc7231 ($self) {
     return $self->at_utc->strftime('%a, %d %b %Y %H:%M:%S GMT');
 }
 
-# %Y-%m-%dT%H:%M:%S%Z
-sub to_w3cdtf ($self) {
+# 2019-12-30T24:60:60Z
+sub to_iso8601 ($self) {
     return $self->strftime('%Y-%m-%dT%H:%M:%S%Z');
 }
 
+# 20190130T241260Z
+sub to_iso8601_compact ($self) {
+    return $self->strftime('%Y%m%dT%H%M%S%Z');
+}
+
 sub duration ( $self, $start, $end ) {
     require Pcore::Util::Date::Duration;
 
