@@ -12,6 +12,10 @@ has pid  => ( init_arg => undef );
 our @DEFERRED_UNLINK;
 
 END {
+
+    # hide warnings
+    local $SIG{__WARN__} = sub { };
+
     for my $path (@DEFERRED_UNLINK) {
         File::Path::remove_tree( $path, safe => 0 );
     }
@@ -20,6 +24,9 @@ END {
 sub DESTROY ($self) {
     return if !defined $self->{temp} || !defined $self->{pid} || $self->{pid} != $$;
 
+    # hide warnings
+    local $SIG{__WARN__} = sub { };
+
     File::Path::remove_tree( $self->{temp}, safe => 0 );
 
     push @DEFERRED_UNLINK, $self->{temp} if -d $self->{temp};
