@@ -337,7 +337,7 @@ sub TO_DUMP1 ( $self, @ ) {
 
 use Inline(
     C => <<'C',
-# include "Pcore/Util/Path.h"
+# include "Pcore/Lib/Path.h"
 
 SV *_parse (SV *path) {
 
@@ -354,7 +354,7 @@ SV *_parse (SV *path) {
         buf = SvPV_nomg_const(path, buf_len);
     }
 
-    PcoreUtilPath *res = parse(buf, buf_len);
+    PcoreLibPath *res = parse(buf, buf_len);
 
     HV *hash = newHV();
     hv_store(hash, "is_abs", 6, newSVuv(res->is_abs), 0);
@@ -407,7 +407,7 @@ SV *_parse (SV *path) {
         hv_store(hash, "suffix", 6, newSV(0), 0);
     }
 
-    destroyPcoreUtilPath(res);
+    destroyPcoreLibPath(res);
 
     sv_2mortal((SV*)newRV_noinc((SV *)hash));
 
