@@ -8,19 +8,19 @@ use Pcore::Util::Sys::Proc qw[:PROC_REDIRECT];
 with qw[Pcore::Util::Src::Filter];
 
 sub decompress ( $self ) {
+    my $res = $self->filter_prettier( parser => 'babel' );
+
+    return $res if !$res;
+
     return $self->filter_eslint;
 }
 
 sub compress ($self) {
-    my $options = $self->dist_cfg->{terser_compress} || $self->src_cfg->{terser_compress};
-
-    return $self->filter_terser( $options->@* );
+    return $self->filter_terser( compress => \1, mangle => \0 );
 }
 
 sub obfuscate ($self) {
-    my $options = $self->dist_cfg->{terser_obfuscate} || $self->src_cfg->{terser_obfuscate};
-
-    return $self->filter_terser( $options->@* );
+    return $self->filter_terser( compress => \1, mangle => \1 );
 }
 
 sub update_log ( $self, $log = undef ) {
@@ -44,34 +44,6 @@ sub update_log ( $self, $log = undef ) {
     return;
 }
 
-sub filter_terser ( $self, @options ) {
-    my $temp = P->file1->tempfile( suffix1 => 'js' );
-
-    P->file->write_bin( $temp, $self->{data} );
-
-    my $proc = P->sys->run_proc(
-        [ 'terser', $temp, @options ],
-        stdout => $PROC_REDIRECT_FH,
-        stderr => $PROC_REDIRECT_FH,
-    )->capture;
-
-    if ( !$proc ) {
-        my $reason;
-
-        if ( $proc->{stderr} ) {
-            my @log = split /\n/sm, $proc->{stderr}->$*;
-
-            $reason = $log[0];
-        }
-
-        return res [ $SRC_FATAL, $reason || $proc->{reason} ];
-    }
-
-    $self->{data} = $proc->{stdout}->$*;
-
-    return $SRC_OK;
-}
-
 sub filer_js_packer ( $self, $obfuscate = undef ) {
     state $packer = do {
         require JavaScript::Packer;
